
Python API
==========

.. py:module:: hictkpy
.. py:currentmodule:: hictkpy


.. autofunction:: is_cooler

.. autofunction:: is_hic

.. autoclass:: File
   :members:
   :special-members: __init__

.. autoclass:: PixelSelector
   :members:

.. py:module:: hictkpy.cooler
.. py:currentmodule:: hictkpy.cooler

.. autoclass:: MultiResFile
   :members:
   :special-members: __init__

.. autoclass:: SingleCellFile
   :members:
   :special-members: __init__
